@@ -19,12 +19,12 @@ SpatialGridDataFrame = function(grid, data,
 
 setMethod("addAttrToGeom", signature(x = "SpatialPixels", y = "data.frame"),
 	function(x, y, match.ID, ...)
-		SpatialPixelsDataFrame(x, y, ...)
+		SpatialPixelsDataFrame(geometry(x), y, ...)
 )
 
 setMethod("addAttrToGeom", signature(x = "SpatialGrid", y = "data.frame"),
 	function(x, y, match.ID, ...)
-		SpatialGridDataFrame(x, y, ...)
+		SpatialGridDataFrame(geometry(x), y, ...)
 )
 
 as.SPixDF.SGDF = function(from) {
@@ -74,17 +74,11 @@ setMethod("coordinates", "SpatialGridDataFrame",
 	function(obj) coordinates(as(obj, "SpatialGrid")))
 
 row.names.SpatialGridDataFrame <- function(x) {
-	warning("row.names order might be wrong!")
-	1:prod(x@grid@cells.dim)
+	#warning("row.names order might be wrong!")
+	#1:prod(x@grid@cells.dim)
+	row.names(x@data)
 }
 
-#setIs("SpatialPixelsDataFrame", "SpatialPointsDataFrame",
-#	coerce = function(from) {
-#		# fullgrid(from) = FALSE ## not needed anymore
-#		new("SpatialPointsDataFrame",
-#			as(from, "SpatialPoints"), data = from@data, coords.nrs = from@coords.nrs)
-#	}, replace = function(obj, value) stop("no replace function for this coercion")
-#)
 as.SpPixDF.SpPoiDF = function(from)
 	new("SpatialPointsDataFrame", as(from, "SpatialPoints"), 
 		data = from@data, coords.nrs = from@coords.nrs)
