@@ -68,6 +68,8 @@ typedef struct polygon {
 void setup_poly_minmax(POLYGON *pl);
 char InPoly(PLOT_POINT q, POLYGON *Poly);
 SEXP R_point_in_polygon_sp(SEXP px, SEXP py, SEXP polx, SEXP poly);
+void sarea(double *heights, int *nx, int *ny, double *w, double *h, 
+	double *sa, int *bycell);
 void spRFindCG( int *n, double *x, double *y, double *xc, double *yc, 
 		double *area );
 void sp_gcdist(double *lon1, double *lon2, double *lat1, double *lat2, 
@@ -89,7 +91,7 @@ void    SP_PREFIX(FindCG)( int n, tPointd *P, tPointd CG, double *Areasum2 );
 void    SP_PREFIX(Centroid3)( tPointd p1, tPointd p2, tPointd p3, tPointd c );
 void SP_PREFIX(spRFindCG_c)( SEXP n, SEXP coords, double *xc, double *yc, 
 		double *area );
-void SP_PREFIX(comm2comment)(char *buf, int *comm, int nps);
+void SP_PREFIX(comm2comment)(char *buf, int bufsiz, int *comm, int nps);
 
 SEXP SP_PREFIX(Polygon_c)(SEXP coords, SEXP n, SEXP hole);
 SEXP SP_PREFIX(Polygons_c)(SEXP pls, SEXP ID);
